@@ -33,6 +33,7 @@
 
 #include <signal.h>
 #include <stdio.h>
+#include <stdint.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
@@ -410,6 +411,7 @@ static void config_input(ATP atp, struct sockaddr_at *faddr, char *packet,
 			rq->miprd.mipr_broadcast = htonl(gMacip.broadcast);
 			rq->miprd.mipr_subnet = htonl(gMacip.mask);
 			len = sizeof(struct macip_req);
+			arp_set (ip, &sat);
 			if (gDebug & DEBUG_MACIP)
 				printf("assigned %s.\n", iptoa(ip));
 		} else {
@@ -553,11 +555,10 @@ static int get_zones(void)
 	saddr.sat_len = sizeof(struct sockaddr_at);
 #endif
 	saddr.sat_family = AF_APPLETALK;
-	if ((se = getservbyname("zip", "ddp")) == NULL) {
-		fprintf(stderr, "Unknown service \"zip/ddp\".\n");
-		return -1;
-	}
-	saddr.sat_port = ntohs(se->s_port);
+	if ((se = getservbyname("zip", "ddp")) == NULL)
+		saddr.sat_port = 6;
+	else
+		saddr.sat_port = ntohs(se->s_port);
 	saddr.sat_addr.s_net = ATADDR_ANYNET;
 	saddr.sat_addr.s_node = ATADDR_ANYNODE;
 
