@@ -16,22 +16,22 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <string.h>
+#include <assert.h>
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
-#include <assert.h>
+#include <string.h>
 #include <time.h>
 
-#include <atalk/util.h>
-#include <atalk/cnid.h>
-#include <atalk/logger.h>
-#include <atalk/volume.h>
-#include <atalk/directory.h>
-#include <atalk/queue.h>
-#include <atalk/bstrlib.h>
 #include <atalk/bstradd.h>
+#include <atalk/bstrlib.h>
+#include <atalk/cnid.h>
+#include <atalk/directory.h>
 #include <atalk/globals.h>
+#include <atalk/logger.h>
+#include <atalk/queue.h>
+#include <atalk/util.h>
+#include <atalk/volume.h>
 
 #include "dircache.h"
 #include "directory.h"
@@ -161,12 +161,9 @@ static int hash_comp_vid_did(const void *key1, const void *key2)
 static hash_t *index_didname;
 
 #undef get16bits
-#if (defined(__GNUC__) && defined(__i386__)) || defined(__WATCOMC__)    \
-    || defined(_MSC_VER) || defined (__BORLANDC__) || defined (__TURBOC__)
+#if defined(__i386__)
 #define get16bits(d) (*((const uint16_t *) (d)))
-#endif
-
-#if !defined (get16bits)
+#else
 #define get16bits(d) ((((uint32_t)(((const uint8_t *)(d))[1])) << 8)    \
                       +(uint32_t)(((const uint8_t *)(d))[0]) )
 #endif
@@ -345,7 +342,7 @@ struct dir *dircache_search_by_did(const struct vol *vol, cnid_t cnid)
         LOG(log_debug, logtype_afpd, "dircache(cnid:%u): {not in cache}", ntohl(cnid));
         dircache_stat.misses++;
     }
-    
+
     return cdir;
 }
 
@@ -439,6 +436,13 @@ int dircache_add(const struct vol *vol,
 
     AFP_ASSERT(dir);
     AFP_ASSERT(ntohl(dir->d_pdid) >= 2);
+
+    if (ntohl(dir->d_did) < CNID_START) {
+        LOG(log_error, logtype_afpd,
+            "dircache_add(): did:%u is less than the allowed %d. Try rebuilding the CNID database for: \"%s\"",
+            ntohl(dir->d_did), CNID_START, cfrombstr(dir->d_u_name));
+    }
+
     AFP_ASSERT(ntohl(dir->d_did) >= CNID_START);
     AFP_ASSERT(dir->d_u_name);
     AFP_ASSERT(dir->d_vid);
@@ -448,7 +452,7 @@ int dircache_add(const struct vol *vol,
     if (dircache->hash_nodecount == dircache_maxsize)
         dircache_evict();
 
-    /* 
+    /*
      * Make sure we don't add duplicates
      */
 
@@ -493,7 +497,7 @@ int dircache_add(const struct vol *vol,
     LOG(log_debug, logtype_afpd, "dircache(did:%u,'%s'): {added}",
         ntohl(dir->d_did), cfrombstr(dir->d_u_name));
 
-   AFP_ASSERT(queue_count == index_didname->hash_nodecount 
+   AFP_ASSERT(queue_count == index_didname->hash_nodecount
            && queue_count == dircache->hash_nodecount);
 
     return 0;
@@ -520,7 +524,7 @@ void dircache_remove(const struct vol *vol _U_, struct dir *dir, int flags)
 
     if (flags & DIDNAME_INDEX) {
         if ((hn = hash_lookup(index_didname, dir)) == NULL) {
-            LOG(log_error, logtype_afpd, "dircache_remove(%u,\"%s\"): not in didname index", 
+            LOG(log_error, logtype_afpd, "dircache_remove(%u,\"%s\"): not in didname index",
                 ntohl(dir->d_did), cfrombstr(dir->d_u_name));
             dircache_dump();
             AFP_PANIC("dircache_remove");
@@ -530,7 +534,7 @@ void dircache_remove(const struct vol *vol _U_, struct dir *dir, int flags)
 
     if (flags & DIRCACHE) {
         if ((hn = hash_lookup(dircache, dir)) == NULL) {
-            LOG(log_error, logtype_afpd, "dircache_remove(%u,\"%s\"): not in dircache", 
+            LOG(log_error, logtype_afpd, "dircache_remove(%u,\"%s\"): not in dircache",
                 ntohl(dir->d_did), cfrombstr(dir->d_u_name));
             dircache_dump();
             AFP_PANIC("dircache_remove");
@@ -542,7 +546,7 @@ void dircache_remove(const struct vol *vol _U_, struct dir *dir, int flags)
         ntohl(dir->d_did), cfrombstr(dir->d_u_name));
 
     dircache_stat.removed++;
-    AFP_ASSERT(queue_count == index_didname->hash_nodecount 
+    AFP_ASSERT(queue_count == index_didname->hash_nodecount
                && queue_count == dircache->hash_nodecount);
 }
 
@@ -571,7 +575,7 @@ int dircache_init(int reqsize)
     }
     if ((dircache = hash_create(dircache_maxsize, hash_comp_vid_did, hash_vid_did)) == NULL)
         return -1;
-    
+
     LOG(log_debug, logtype_afpd, "dircache_init: done. max dircache size: %u", dircache_maxsize);
 
     /* Initialize did/name index hashtable */
