@@ -34,39 +34,39 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <stdio.h>
-
-#include <string.h>
-#include <stdlib.h>
+#include <arpa/inet.h>
 #include <errno.h>
-#include <time.h>
+#include <netdb.h>
+#include <netinet/in.h>
+#include <stdbool.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include <sys/param.h>
 #include <sys/socket.h>
-#include <netinet/in.h>
-#include <arpa/inet.h>
-#include <netdb.h>
-#include <stdbool.h>
+#include <time.h>
+#include <unistd.h>
 
 #include <atalk/adouble.h>
-#include <atalk/vfs.h>
-#include <atalk/logger.h>
 #include <atalk/afp.h>
-#include <atalk/util.h>
 #include <atalk/cnid.h>
-#include <atalk/unix.h>
 #include <atalk/fce_api.h>
 #include <atalk/globals.h>
+#include <atalk/logger.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
 
-#include "fork.h"
-#include "file.h"
-#include "directory.h"
 #include "desktop.h"
+#include "directory.h"
+#include "file.h"
+#include "fork.h"
 #include "volume.h"
 
 // ONLY USED IN THIS FILE
 #include "fce_api_internal.h"
 
-extern int afprun_bg(int root, char *cmd);
+extern int afprun_bg(char *cmd);
 
 /* We store our connection data here */
 static struct udp_entry udp_socket_list[FCE_MAX_UDP_SOCKS];
@@ -182,7 +182,7 @@ void fce_cleanup(void)
  * Construct a UDP packet for our listeners and return packet size
  * */
 static ssize_t build_fce_packet(const AFPObj *obj,
-                                char *iobuf,
+                                unsigned char *iobuf,
                                 fce_ev_t event,
                                 const char *path,
                                 const char *oldpath,
@@ -190,7 +190,7 @@ static ssize_t build_fce_packet(const AFPObj *obj,
                                 const char *user,
                                 uint32_t event_id)
 {
-    char *p = iobuf;
+    unsigned char *p = iobuf;
     size_t pathlen;
     ssize_t datalen = 0;
     uint16_t uint16;
@@ -298,7 +298,7 @@ static ssize_t build_fce_packet(const AFPObj *obj,
  * We don't give return code because all errors are handled internally (I hope..)
  * */
 static void send_fce_event(const AFPObj *obj, int event, const char *path, const char *oldpath)
-{    
+{
     static bool first_event = true;
     static uint32_t event_id = 0; /* the unique packet couter to detect packet/data loss. Going from 0xFFFFFFFF to 0x0 is a valid increment */
     static char *user;
@@ -368,10 +368,17 @@ static void send_fce_event(const AFPObj *obj, int event, const char *path, const
             bformata(cmd, " -S '%s'", bdata(boldpath));
             bdestroy(boldpath);
         }
-        (void)afprun_bg(1, bdata(cmd));
+        (void)afprun_bg(bdata(cmd));
         bdestroy(cmd);
     }
 
+    if (obj->options.fce_sendwait > 0 && obj->options.fce_sendwait < 1000) {
+	struct timespec t;
+	t.tv_sec  = 0;
+	t.tv_nsec = 1000 * 1000 * obj->options.fce_sendwait;
+	while(nanosleep(&t, NULL));
+    }
+
     for (int i = 0; i < udp_sockets; i++) {
         int sent_data = 0;
         struct udp_entry *udp_entry = udp_socket_list + i;
@@ -386,7 +393,7 @@ static void send_fce_event(const AFPObj *obj, int event, const char *path, const
             udp_entry->sock = socket(udp_entry->addrinfo.ai_family,
                                      udp_entry->addrinfo.ai_socktype,
                                      udp_entry->addrinfo.ai_protocol);
-            
+
             if (udp_entry->sock == -1) {
                 /* failed again, so go to rest again */
                 LOG(log_error, logtype_fce, "Cannot recreate socket for fce UDP connection: errno %d", errno  );
@@ -581,7 +588,11 @@ int fce_register(const AFPObj *obj, fce_ev_t event, const char *path, const char
 
     switch (event) {
     case FCE_FILE_MODIFY:
-        save_close_event(obj, path);
+        if (obj->options.fce_fmodwait != 0){
+            save_close_event(obj, path);
+        } else {
+            send_fce_event(obj, event, path, oldpath);
+        }
         break;
     default:
         send_fce_event(obj, event, path, oldpath);
