@@ -105,6 +105,18 @@ void *get_finderinfo(const struct vol *vol, const char *upath, struct adouble *a
             memcpy((char *)data + FINDERINFO_FRFLAGOFF, &ashort, sizeof(ashort));
         }
     }
+#ifdef __APPLE__
+    /* If no adouble finder information was found, check for native macOS info */
+    if (chk_ext && (vol->v_adouble == AD_VERSION_EA))
+    {
+        char NativeFinderInfo[ADEDLEN_FINDERI] ={'\0'};
+        if (ad_open_native_finderinfo(upath, NativeFinderInfo))
+        {
+            memcpy(data, NativeFinderInfo, ADEDLEN_FINDERI);
+            chk_ext = 0;
+        }
+    }
+#endif
 
     if (islink && !vol_syml_opt(vol)) {
         uint16_t linkflag;
@@ -1460,7 +1472,7 @@ int copyfile(struct vol *s_vol,
         return AFPERR_EXIST;
     }
     size_t copybuf_len = 0;
-    char* copybuf;
+    uint8_t* copybuf;
 
     if (s_vol->v_obj->proto == AFPPROTO_DSI)
     {
