@@ -7,35 +7,35 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <errno.h>
 #include <sys/param.h>
 
-#include <atalk/adouble.h>
-#include <atalk/vfs.h>
-#include <atalk/afp.h>
-#include <atalk/util.h>
-#include <atalk/cnid.h>
-#include <atalk/logger.h>
-#include <atalk/unix.h>
-#include <atalk/bstrlib.h>
-#include <atalk/bstradd.h>
 #include <atalk/acl.h>
-#include <atalk/globals.h>
-#include <atalk/fce_api.h>
-#include <atalk/netatalk_conf.h>
+#include <atalk/adouble.h>
+#include <atalk/afp.h>
+#include <atalk/bstradd.h>
+#include <atalk/bstrlib.h>
+#include <atalk/cnid.h>
 #include <atalk/errchk.h>
+#include <atalk/fce_api.h>
+#include <atalk/globals.h>
+#include <atalk/logger.h>
+#include <atalk/netatalk_conf.h>
+#include <atalk/unix.h>
+#include <atalk/util.h>
+#include <atalk/vfs.h>
 
-#include "directory.h"
-#include "dircache.h"
 #include "desktop.h"
-#include "volume.h"
-#include "fork.h"
+#include "dircache.h"
+#include "directory.h"
 #include "file.h"
 #include "filedir.h"
+#include "fork.h"
 #include "unix.h"
+#include "volume.h"
 
 int afp_getfildirparams(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *rbuf, size_t *rbuflen)
 {
@@ -126,7 +126,7 @@ int afp_getfildirparams(AFPObj *obj _U_, char *ibuf, size_t ibuflen _U_, char *r
     rbuf += sizeof( fbitmap );
     dbitmap = htons( dbitmap );
     memcpy( rbuf, &dbitmap, sizeof( dbitmap ));
-    rbuf += sizeof( dbitmap ) + sizeof( u_char );
+    rbuf += sizeof( dbitmap ) + sizeof( uint8_t );
     *rbuf = 0;
 
     return( AFP_OK );
@@ -183,7 +183,7 @@ int afp_setfildirparams(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf
     /*
      * If ibuf is odd, make it even.
      */
-    if ((u_long)ibuf & 1 ) {
+    if ((intptr_t)ibuf & 1 ) {
         ibuf++;
     }
 
@@ -215,9 +215,9 @@ int check_name(const struct vol *vol, char *name)
     return 0;
 }
 
-/* ------------------------- 
+/* -------------------------
     move and rename sdir:oldname to curdir:newname in volume vol
-    special care is needed for lock   
+    special care is needed for lock
 */
 static int moveandrename(const AFPObj *obj,
                          struct vol *vol,
@@ -281,7 +281,7 @@ static int moveandrename(const AFPObj *obj,
      * oldunixname now points to either
      *   a) full pathname of the source fs object (if renameat is not available)
      *   b) the oldname (renameat is available)
-     * we are in the dest folder so we need to use 
+     * we are in the dest folder so we need to use
      *   a) oldunixname for ad_open
      *   b) fchdir sdir_fd before e.g. ad_open or use *at functions where appropriate
      */
@@ -298,7 +298,7 @@ static int moveandrename(const AFPObj *obj,
         uint16_t bshort;
 
         ad_getattr(adp, &bshort);
-        
+
         ad_close(adp, ADFLAGS_HF);
         if (!(vol->v_ignattr & ATTRBIT_NORENAME) && (bshort & htons(ATTRBIT_NORENAME))) {
             rc = AFPERR_OLOCK;
@@ -313,7 +313,7 @@ static int moveandrename(const AFPObj *obj,
         }
     }
 
-    if (NULL == (upath = mtoupath(vol, newname, curdir->d_did, utf8_encoding(vol->v_obj)))){ 
+    if (NULL == (upath = mtoupath(vol, newname, curdir->d_did, utf8_encoding(vol->v_obj)))){
         rc = AFPERR_PARAM;
         goto exit;
     }
@@ -363,7 +363,7 @@ static int moveandrename(const AFPObj *obj,
                 of_rename(vol, opened, sdir, oldname, curdir, newname);
         }
     } else {
-        rc = renamedir(vol, sdir_fd, oldunixname, upath, sdir, curdir, newname);
+        rc = renamedir(vol, sdir_fd, oldunixname, upath, curdir, newname);
     }
     if ( rc == AFP_OK && id ) {
         /* renaming may have moved the file/dir across a filesystem */
@@ -475,7 +475,7 @@ int afp_rename(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, size
     if (!plen) {
         return AFP_OK; /* newname == oldname same dir */
     }
-    
+
     rc = moveandrename(obj, vol, sdir, -1, oldname, newname, isdir);
     if ( rc == AFP_OK ) {
         setvoltime(obj, vol );
@@ -484,7 +484,7 @@ int afp_rename(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, size
     return( rc );
 }
 
-/* 
+/*
  * Recursivley delete vetoed files and directories if the volume option is set
  *
  * @param vol   (r) volume handle
@@ -655,7 +655,7 @@ int afp_delete(AFPObj *obj, char *ibuf, size_t ibuflen _U_, char *rbuf _U_, size
 				fce_register(obj, FCE_FILE_DELETE, fullpathname(upath), NULL);
                 if (vol->v_tm_used < s_path->st.st_size)
                     vol->v_tm_used = 0;
-                else 
+                else
                     vol->v_tm_used -= s_path->st.st_size;
             }
             struct dir *cachedfile;
