@@ -18,37 +18,33 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <string.h>
-#include <strings.h>
+#include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
-#include <stdbool.h>
-#include <inttypes.h>
+#include <string.h>
+#include <strings.h>
 #include <time.h>
 #include <utime.h>
 
-#include <atalk/list.h>
-#include <atalk/errchk.h>
-#include <atalk/util.h>
-#include <atalk/logger.h>
-#if USE_BUILTIN_TALLOC
-#include <atalk/talloc.h>
-#else
+#include <glib.h>
 #include <talloc.h>
-#endif
-#include <atalk/dalloc.h>
+
 #include <atalk/byteorder.h>
-#include <atalk/netatalk_conf.h>
-#include <atalk/volume.h>
-#include <atalk/spotlight.h>
 #include <atalk/compat.h>
+#include <atalk/dalloc.h>
+#include <atalk/errchk.h>
+#include <atalk/list.h>
+#include <atalk/logger.h>
+#include <atalk/netatalk_conf.h>
+#include <atalk/spotlight.h>
+#include <atalk/util.h>
+#include <atalk/volume.h>
 
 #include "directory.h"
 #include "etc/spotlight/sparql_parser.h"
 
-#include <glib.h>
-
 #define MAX_SL_RESULTS 20
 
 struct slq_state_names {
@@ -862,7 +858,8 @@ static int sl_rpc_openQuery(AFPObj *obj,
     /* convert spotlight query charset to host charset */
     sl_query = dalloc_value_for_key(query, "DALLOC_CTX", 0,
                                     "DALLOC_CTX", 1,
-                                    "kMDQueryString");
+                                    "kMDQueryString",
+                                    "char *");
     if (sl_query == NULL) {
         EC_FAIL;
     }
@@ -893,14 +890,14 @@ static int sl_rpc_openQuery(AFPObj *obj,
     slq->slq_ctx2 = *uint64;
 
     reqinfo = dalloc_value_for_key(query, "DALLOC_CTX", 0, "DALLOC_CTX", 1,
-                                   "kMDAttributeArray");
+                                   "kMDAttributeArray", "sl_array_t");
     if (reqinfo == NULL) {
         EC_FAIL;
     }
     slq->slq_reqinfo = talloc_steal(slq, reqinfo);
 
     scope_array = dalloc_value_for_key(query, "DALLOC_CTX", 0, "DALLOC_CTX", 1,
-                                       "kMDScopeArray");
+                                       "kMDScopeArray", "sl_array_t");
     if (scope_array == NULL) {
         scope = g_uri_escape_string(v->v_path,
                                     G_URI_RESERVED_CHARS_ALLOWED_IN_PATH, TRUE);
@@ -925,14 +922,14 @@ static int sl_rpc_openQuery(AFPObj *obj,
     LOG(log_debug, logtype_sl, "Search scope: \"%s\"", slq->slq_scope);
 
     cnids = dalloc_value_for_key(query, "DALLOC_CTX", 0, "DALLOC_CTX", 1,
-                                 "kMDQueryItemArray");
+                                 "kMDQueryItemArray", "sl_array_t");
     if (cnids) {
         EC_ZERO_LOG( sl_createCNIDArray(slq, cnids->ca_cnids) );
     }
 
     ret = map_spotlight_to_sparql_query(slq, &sparql_query);
     if (ret != 0) {
-        LOG(log_debug, logtype_sl, "mapping retured non-zero");
+        LOG(log_debug, logtype_sl, "mapping returned non-zero");
         EC_FAIL;
     }
     LOG(log_debug, logtype_sl, "SPARQL query: \"%s\"", sparql_query);
@@ -1089,7 +1086,8 @@ static int sl_rpc_storeAttributesForOIDArray(const AFPObj *obj,
      * that seems to be candidates for updating filesystem metadata.
      */
 
-    if ((sl_time = dalloc_value_for_key(query, "DALLOC_CTX", 0, "DALLOC_CTX", 1, "DALLOC_CTX", 1, "kMDItemFSContentChangeDate"))) {
+    if ((sl_time = dalloc_value_for_key(query, "DALLOC_CTX", 0, "DALLOC_CTX", 1, "DALLOC_CTX", 1,
+                                        "kMDItemFSContentChangeDate", "sl_time_t"))) {
         struct utimbuf utimes;
         utimes.actime = utimes.modtime = sl_time->tv_sec;
         utime(path, &utimes);
