@@ -16,28 +16,25 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
-#include <string.h>
-#include <strings.h>
+#include <errno.h>
+#include <inttypes.h>
+#include <stdbool.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <errno.h>
-#include <stdbool.h>
-#include <inttypes.h>
+#include <string.h>
+#include <strings.h>
 
-#include <atalk/errchk.h>
-#include <atalk/util.h>
-#include <atalk/logger.h>
-#if USE_BUILTIN_TALLOC
-#include <atalk/talloc.h>
-#else
 #include <talloc.h>
-#endif
-#include <atalk/dalloc.h>
+
 #include <atalk/byteorder.h>
-#include <atalk/netatalk_conf.h>
-#include <atalk/volume.h>
+#include <atalk/dalloc.h>
 #include <atalk/dsi.h>
+#include <atalk/errchk.h>
+#include <atalk/logger.h>
+#include <atalk/netatalk_conf.h>
 #include <atalk/spotlight.h>
+#include <atalk/util.h>
+#include <atalk/volume.h>
 
 #define MAX_SLQ_DAT (DSI_DATASIZ - 64)
 #define MAX_SLQ_TOC 8192
@@ -246,7 +243,7 @@ static int sl_pack_CNID(sl_cnids_t *cnids, char *buf, int offset, char *toc_buf,
             offset += 8;
         }
     }
-    
+
 EC_CLEANUP:
     if (ret != 0)
         return -1;
@@ -524,7 +521,7 @@ static int sl_unpack_CNID(DALLOC_CTX *query, const char *buf, int offset, int le
     if (length <= 16)
         /* that's permitted, it's an empty array */
         goto EC_CLEANUP;
-    
+
     query_data64 = sl_unpack_uint64(buf, offset, encoding);
     count = query_data64 & 0xffff;
 
@@ -671,7 +668,7 @@ static int sl_unpack_cpx(DALLOC_CTX *query,
     default:
         EC_FAIL;
     }
-            
+
 EC_CLEANUP:
     if (ret != 0)
         roffset = -1;
