@@ -92,7 +92,6 @@
 #include <atalk/logger.h>
 #include <netatalk/at.h>
 #include <atalk/atp.h>
-#include <atalk/paths.h>
 #include <atalk/unicode.h>
 
 #include "printer.h"
@@ -103,7 +102,7 @@
 #include  "print_cups.h"
 #endif
 
-#ifdef MUSL
+#ifndef HAVE_RRESVPORT
 int
 rresvport (int *alport)
 {
