@@ -10,18 +10,11 @@
 #include "config.h"
 #endif /* HAVE_CONFIG_H */
 
+#include <arpa/inet.h>
 #include <stdbool.h>
 #include <stdint.h>
 #include <stdlib.h>
 #include <string.h>
-#include <arpa/inet.h>
-
-#include <atalk/logger.h>
-#include <atalk/afp.h>
-#include <atalk/uam.h>
-#include <atalk/util.h>
-#include <atalk/compat.h>
-#include <atalk/globals.h>
 
 /* Kerberos includes */
 #ifdef HAVE_GSSAPI_GSSAPI_H
@@ -38,6 +31,13 @@
 #endif /* HAVE_KRB5_KRB5_H */
 #endif /* HAVE_KERBEROS */
 
+#include <atalk/afp.h>
+#include <atalk/compat.h>
+#include <atalk/globals.h>
+#include <atalk/logger.h>
+#include <atalk/uam.h>
+#include <atalk/util.h>
+
 #define LOG_UAMS(log_level, ...) \
     LOG(log_level, logtype_uams, __VA_ARGS__)
 
@@ -220,7 +220,7 @@ static int wrap_sessionkey(gss_ctx_id_t context, struct session_info *sinfo)
     /* store the wrapped session key in afpd's session_info struct */
     if (NULL == (sinfo->cryptedkey = malloc(wrap_buff.length))) {
         LOG_UAMS(log_error,
-                 "wrap_sessionkey: out of memory tyring to allocate %u bytes",
+                 "wrap_sessionkey: out of memory trying to allocate %u bytes",
                  wrap_buff.length);
         ret = 1;
     } else {
@@ -276,7 +276,7 @@ static int accept_sec_context(gss_ctx_id_t *context,
     return 0;
 }
 
-static int do_gss_auth(void *obj,
+static int do_gss_auth(void *obj _U_,
                        char *ibuf, size_t ibuflen,
                        char *rbuf, int *rbuflen,
                        char *username, size_t ulen,
@@ -340,9 +340,9 @@ cleanup_client_name:
  * login-session id. None of the data provided by the client up to this
  * point is trustworthy as we'll have a signed ticket to parse in logincont.
  */
-static int gss_login(void *obj,
-                     struct passwd **uam_pwd,
-                     char *ibuf, size_t ibuflen,
+static int gss_login(void *obj _U_,
+                     struct passwd **uam_pwd _U_,
+                     char *ibuf _U_, size_t ibuflen _U_,
                      char *rbuf, size_t *rbuflen)
 {
     *rbuflen = 0;
@@ -481,7 +481,7 @@ static void gss_logout(void)
 }
 
 static int gss_login_ext(void *obj,
-                         char *uname,
+                         char *uname _U_,
                          struct passwd **uam_pwd,
                          char *ibuf, size_t ibuflen,
                          char *rbuf, size_t *rbuflen)
@@ -606,7 +606,7 @@ krb5_cleanup:
         goto exit;
 
     char principal[255];
-    size_t len = snprintf(principal, sizeof(principal), "%s/%s@%s",
+    size_t len _U_ = snprintf(principal, sizeof(principal), "%s/%s@%s",
                           obj->options.k5service, obj->options.fqdn, obj->options.k5realm);
     (void)set_principal(obj, principal);
     rv = 0;
