@@ -108,7 +108,7 @@ static int ad_mkrf(const char *path);
 static int ad_header_read(const char *path, struct adouble *ad, const struct stat *hst);
 static int ad_header_upgrade(struct adouble *ad, const char *name);
 
-#ifdef HAVE_EAFD
+#if defined (HAVE_EAFD) && defined (SOLARIS)
 static int ad_mkrf_ea(const char *path);
 #endif
 static int ad_header_read_ea(const char *path, struct adouble *ad, const struct stat *hst);
@@ -126,7 +126,7 @@ static struct adouble_fops ad_adouble = {
 };
 
 static struct adouble_fops ad_adouble_ea = {
-#ifdef HAVE_EAFD
+#if defined (HAVE_EAFD) && defined (SOLARIS)
     &ad_path_ea,
     &ad_mkrf_ea,
 #else
@@ -411,7 +411,7 @@ static int new_ad_header(struct adouble *ad, const char *path, struct stat *stp,
 static int parse_entries(struct adouble *ad, uint16_t nentries, size_t valid_data_len)
 {
     uint32_t   eid, len, off;
-    uint8_t *buf = ad->ad_data + AD_HEADER_LEN;
+    uint8_t *buf = (uint8_t *) ad->ad_data + AD_HEADER_LEN;
 
     /* now, read in the entry bits */
     for (; nentries > 0; nentries-- ) {
@@ -989,6 +989,30 @@ static int ad2openflags(const struct adouble *ad, int adfile, int adflags)
 
     return oflags;
 }
+#ifdef __APPLE__
+int ad_open_native_finderinfo(const char *path, char *ret)
+{
+    ssize_t size;
+    LOG(log_debug, logtype_ad,
+        "ad_open_native_finderinfo(\"%s\"): BEGIN",
+        fullpathname(path));
+    size = sys_getxattr(path,EA_FINFO,0,0);
+    if (size < 0) {
+        LOG(log_debug, logtype_ad,
+            "ad_open_native_finderinfo(\"%s\"): Native macOS FinderInfo not found",
+            fullpathname(path));
+        return 0;
+    }
+    else
+    {
+        sys_getxattr(path,EA_FINFO,ret,ADEDLEN_FINDERI);
+        LOG(log_debug, logtype_ad,
+            "ad_open_native_finderinfo(\"%s\"): Native macOS FinderInfo found",
+            fullpathname(path));
+        return 1;
+    }
+}
+#endif
 
 static int ad_open_df(const char *path, int adflags, mode_t mode, struct adouble *ad)
 {
@@ -1249,6 +1273,11 @@ static int ad_open_hf_ea(const char *path, int adflags, int mode _U_, struct ado
         }
     }
 
+#ifdef __APPLE__
+    char * FinderInfo;
+    char NativeFinderInfo[ADEDLEN_FINDERI]={'\0'};
+#endif
+
     /* Read the adouble header in and parse it.*/
     if (ad->ad_ops->ad_header_read(path, ad, NULL) != 0) {
         if (!(adflags & ADFLAGS_CREATE)) {
@@ -1272,10 +1301,23 @@ static int ad_open_hf_ea(const char *path, int adflags, int mode _U_, struct ado
         /* Create one */
         EC_NEG1_LOG(new_ad_header(ad, path, NULL, adflags));
         ad->ad_mdp->adf_flags |= O_CREAT; /* mark as just created */
+#ifdef __APPLE__
+        /* Read in FinderInfo from macOS */
+        FinderInfo = ad_entry(ad, ADEID_FINDERI);
+        if (ad_open_native_finderinfo(path, NativeFinderInfo))
+            memcpy(FinderInfo, NativeFinderInfo, ADEDLEN_FINDERI);
+#endif
         ad_flush(ad);
         LOG(log_debug, logtype_ad, "ad_open_hf_ea(\"%s\"): created metadata EA", path);
     }
 
+#ifdef __APPLE__
+        /* Read in FinderInfo from macOS */
+        FinderInfo = ad_entry(ad, ADEID_FINDERI);
+        if (ad_open_native_finderinfo(path, NativeFinderInfo))
+            memcpy(FinderInfo, NativeFinderInfo, ADEDLEN_FINDERI);
+#endif
+
     if (ad_meta_fileno(ad) != -1)
         ad->ad_mdp->adf_refcount++;
     ad->ad_rlen = ad_reso_size(path, adflags, ad);
@@ -1393,7 +1435,7 @@ static int ad_open_rf_ea(const char *path, int adflags, int mode, struct adouble
     int oflags;
     int opened = 0;
     int closeflags = adflags & (ADFLAGS_DF | ADFLAGS_HF);
-#ifndef HAVE_EAFD
+#ifndef SOLARIS
     const char *rfpath;
     struct stat st;
 #endif
@@ -1416,7 +1458,7 @@ static int ad_open_rf_ea(const char *path, int adflags, int mode, struct adouble
         EC_NEG1_LOG( ad->ad_rlen = ad_reso_size(path, adflags, ad));
         goto EC_CLEANUP;
     }
-#ifdef HAVE_EAFD
+#if defined (HAVE_EAFD) && defined (SOLARIS)
     if (ad_meta_fileno(ad) < 0)
         EC_FAIL;
     if ((ad_reso_fileno(ad) = sys_getxattrfd(ad_meta_fileno(ad), AD_EA_RESO, oflags)) == -1) {
@@ -1588,7 +1630,11 @@ static bool ad_entry_check_size(uint32_t eid,
 		[ADEID_SHORTNAME] = {ADEDLEN_SHORTNAME, false, false},
 		[ADEID_AFPFILEI] = {ADEDLEN_AFPFILEI, true, false},
 		[ADEID_DID] = {ADEDLEN_DID, true, false},
+#ifdef __APPLE__
+		[ADEID_PRIVDEV] = {ADEDLEN_PRIVDEV, false, false},
+#else
 		[ADEID_PRIVDEV] = {ADEDLEN_PRIVDEV, true, false},
+#endif
 		[ADEID_PRIVINO] = {ADEDLEN_PRIVINO, true, false},
 		[ADEID_PRIVSYN] = {ADEDLEN_PRIVSYN, true, false},
 		[ADEID_PRIVID] = {ADEDLEN_PRIVID, true, false},
@@ -1722,8 +1768,14 @@ const char *ad_path_osx(const char *path, int adflags _U_)
         pathbuf[ 0 ] = '\0';
         slash = buf;
     }
+#ifdef __APPLE__
+    /* macos abstracts the resource fork as "filename/..namedfork/rsrc" which we can treat as a file */
+    strlcat( pathbuf, buf, MAXPATHLEN +1);
+    strlcat( pathbuf, "/..namedfork/rsrc", MAXPATHLEN  +1);
+#else
     strlcat( pathbuf, "._", MAXPATHLEN  +1);
     strlcat( pathbuf, slash, MAXPATHLEN +1);
+#endif
     return pathbuf;
 }
 
