@@ -90,7 +90,7 @@ ssize_t ad_write(struct adouble *ad, uint32_t eid, off_t off, int end, const cha
         if ( ad->ad_rlen < off + cc )
             ad->ad_rlen = off + cc;
     } else {
-        return -1; /* we don't know how to write if it's not a ressource or data fork */
+        return -1; /* we don't know how to write if it's not a resource or data fork */
     }
 
     if (ret != 0)
@@ -217,12 +217,12 @@ static int copy_all(const int dfd, const void *buf,
 /* --------------------------
  * copy only the fork data stream
 */
-int copy_fork(int eid, struct adouble *add, struct adouble *ads, char *buf, size_t buflen)
+int copy_fork(int eid, struct adouble *add, struct adouble *ads, uint8_t *buf, size_t buflen)
 {
     ssize_t cc;
     int     err = 0;
-    char    fixedbuf[8192];
-    char    *filebuf;
+    uint8_t fixedbuf[8192];
+    uint8_t *filebuf;
     int     sfd, dfd;
 
     if (buf != NULL && buflen > sizeof(fixedbuf)) {
