@@ -2,8 +2,6 @@
 #include "config.h"
 #endif
 
-#ifdef DEBUG
-
 #include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -16,9 +14,7 @@ static const char	hexdig[] = "0123456789ABCDEF";
 #define BPXLEN	50
 #define BPALEN	18
 
-void bprint( data, len )
-    char	*data;
-    int		len;
+void bprint( char *data, int len )
 {
     char	xout[ BPXLEN ], aout[ BPALEN ];
     int         i;
@@ -50,4 +46,3 @@ void bprint( data, len )
 
     printf("(end)\n");
 }
-#endif
