@@ -32,7 +32,7 @@ char   u_null[] = { 0, 0, 0, 0 };
 			FAIL(FPGetIcon(Conn,  dt, u_null, u_null, 1, 256 ))
 		}
 		else if (ret) {
-			failed();
+			test_failed();
 		}
 #endif
 	}
@@ -44,8 +44,6 @@ char   u_null[] = { 0, 0, 0, 0 };
 /* ----------- */
 void FPGetIcon_test()
 {
-    fprintf(stdout,"===================\n");
-    fprintf(stdout,"FPGetIcon page 186\n");
-    fprintf(stdout,"-------------------\n");
+    ENTER_TESTSET
 	test115();
 }
