@@ -18,33 +18,26 @@ unsigned int ret;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
 	FAIL (FPCreateFile(Conn, vol,  0, DIRDID_ROOT , name))
-	if (!Mac) {
-		sprintf(temp, "%s/%s", Path, ndir);
-		if (!Quiet) {
-			fprintf(stdout, "mkdir(%s)\n", temp);
-		}
-		if (mkdir(temp, 0777)) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED mkdir %s %s\n", temp, strerror(errno));
-			}
-			test_failed();
-		}
-		// Workaround for musl mkdir() not setting the right permissions
-		if (chmod(temp, 0777)) {
-			test_failed();
-		}
+
+	sprintf(temp, "%s/%s", Path, ndir);
+	if (!Quiet) {
+		fprintf(stdout, "mkdir(%s)\n", temp);
 	}
-	else {
-		dir  = FPCreateDir(Conn,vol, DIRDID_ROOT , ndir);
-		if (!dir) {
-			test_failed();
+	if (mkdir(temp, 0777)) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED mkdir %s %s\n", temp, strerror(errno));
 		}
+		test_failed();
+	}
+	// Workaround for musl mkdir() not setting the right permissions
+	if (chmod(temp, 0777)) {
+		test_failed();
 	}
 
 	ret = FPMoveAndRename(Conn, vol, DIRDID_ROOT, DIRDID_ROOT, name, name1);
@@ -78,33 +71,26 @@ unsigned int ret;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
 	FAIL (FPCreateFile(Conn, vol,  0, DIRDID_ROOT , name))
-	if (!Mac) {
-		sprintf(temp, "%s/%s", Path, ndir);
-		if (!Quiet) {
-			fprintf(stdout, "mkdir(%s)\n", temp);
-		}
-		if (mkdir(temp, 0777)) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED mkdir %s %s\n", temp, strerror(errno));
-			}
-			test_failed();
-		}
-		// Workaround for musl mkdir() not setting the right permissions
-		if (chmod(temp, 0777)) {
-			test_failed();
-		}
+
+	sprintf(temp, "%s/%s", Path, ndir);
+	if (!Quiet) {
+		fprintf(stdout, "mkdir(%s)\n", temp);
 	}
-	else {
-		dir  = FPCreateDir(Conn,vol, DIRDID_ROOT , ndir);
-		if (!dir) {
-			test_failed();
+	if (mkdir(temp, 0777)) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED mkdir %s %s\n", temp, strerror(errno));
 		}
+		test_failed();
+	}
+	// Workaround for musl mkdir() not setting the right permissions
+	if (chmod(temp, 0777)) {
+		test_failed();
 	}
 
 	fork = FPOpenFork(Conn, vol, OPENFORK_RSCS , bitmap ,DIRDID_ROOT, name, OPENACC_WR | OPENACC_RD);
@@ -139,8 +125,8 @@ uint16_t vol = VolID;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -151,9 +137,7 @@ uint16_t vol = VolID;
 
 	FAIL (FPCreateFile(Conn, vol,  0, DIRDID_ROOT , name))
 
-	if (!Mac) {
-		delete_unix_md(Path,"", name);
-	}
+	delete_unix_md(Path,"", name);
 	FAIL (FPMoveAndRename(Conn, vol, DIRDID_ROOT, dir, name, ""))
 
 	FAIL (FPDelete(Conn, vol,  dir , name))
@@ -176,8 +160,8 @@ int id1;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -190,30 +174,26 @@ int id1;
 
 	id = get_fid(Conn, vol, dir , name1);
 
-	if (!Mac) {
-		sprintf(temp,"%s/%s/%s", Path, name, name1);
-		sprintf(temp1,"%s/%s/%s", Path, name, name2);
-		if (rename(temp, temp1) < 0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-			}
-			test_failed();
+	sprintf(temp,"%s/%s/%s", Path, name, name1);
+	sprintf(temp1,"%s/%s/%s", Path, name, name2);
+	if (rename(temp, temp1) < 0) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 		}
+		test_failed();
 	}
-	else {
-		FAIL (FPMoveAndRename(Conn, vol, dir, dir, name1, name2))
-	}
+
 	id1 = get_fid(Conn, vol, dir , name2);
 	if (id != id1) {
 		if (!Quiet) {
-			fprintf(stdout,"\tFAILED id are not the same %d %d\n", ntohl(id), ntohl(id1));
+			fprintf(stdout,"\tNOTE id are not the same %d %d\n", ntohl(id), ntohl(id1));
 		}
 		test_failed();
 	}
 	FAIL (FPDelete(Conn, vol,  dir , name2))
 	FAIL (FPDelete(Conn, vol,  DIRDID_ROOT, name))
 test_exit:
-	exit_test("FPMoveAndRename:test302: file renamed by someone else, cnid not updated");
+	exit_test("FPMoveAndRename:test302: file renamed by someone else, cnid updated");
 }
 
 /* ------------------------- */
@@ -229,8 +209,8 @@ uint16_t vol = VolID;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -248,22 +228,16 @@ uint16_t vol = VolID;
 	FAIL (FPGetFileDirParams(Conn, vol, dir, file, bitmap, 0))
 	FAIL (FPGetFileDirParams(Conn, vol, dir1, file, bitmap, 0))
 
-	if (!Mac) {
-		sprintf(temp,"%s/%s/%s", Path, name, file);
-		sprintf(temp1,"%s/%s/%s", Path, name1, file);
-		if (!Quiet) {
-			fprintf (stdout, "rename %s --> %s\n", temp, temp1);
-		}
-		if (rename(temp, temp1) < 0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-			}
-			test_failed();
-		}
-
+	sprintf(temp,"%s/%s/%s", Path, name, file);
+	sprintf(temp1,"%s/%s/%s", Path, name1, file);
+	if (!Quiet) {
+		fprintf (stdout, "rename %s --> %s\n", temp, temp1);
 	}
-	else {
-		FAIL (FPMoveAndRename(Conn, vol, dir, dir1, file, file))
+	if (rename(temp, temp1) < 0) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
+		}
+		test_failed();
 	}
 
     bitmap = (1<<FILPBIT_LNAME) | (1<<FILPBIT_FNUM );
@@ -292,8 +266,8 @@ uint16_t vol = VolID;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -309,35 +283,30 @@ uint16_t vol = VolID;
     bitmap = (1<<FILPBIT_LNAME) | (1<<FILPBIT_FNUM );
 	FAIL (FPGetFileDirParams(Conn, vol, dir, file, bitmap, 0))
 
-	if (!Mac) {
-		sprintf(temp,"%s/%s/%s", Path, name, file);
-		sprintf(temp1,"%s/%s/%s", Path, name1, file);
-		if (!Quiet) {
-			fprintf (stdout, "rename %s --> %s\n", temp, temp1);
-		}
-		if (rename(temp, temp1) < 0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-			}
-			test_failed();
-		}
-
-        if (adouble == AD_V2) {
-            sprintf(temp,"%s/%s/.AppleDouble/%s", Path, name, file);
-            sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, file);
-	    if (!Quiet) {
+	sprintf(temp,"%s/%s/%s", Path, name, file);
+	sprintf(temp1,"%s/%s/%s", Path, name1, file);
+	if (!Quiet) {
 		fprintf (stdout, "rename %s --> %s\n", temp, temp1);
-	    }
-            if (rename(temp, temp1) < 0) {
+	}
+	if (rename(temp, temp1) < 0) {
 		if (!Quiet) {
 			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 		}
 		test_failed();
-            }
-        }
 	}
-	else {
-		FAIL (FPMoveAndRename(Conn, vol, dir, dir1, file, file))
+
+	if (adouble == AD_V2) {
+		sprintf(temp,"%s/%s/.AppleDouble/%s", Path, name, file);
+		sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, file);
+	if (!Quiet) {
+	fprintf (stdout, "rename %s --> %s\n", temp, temp1);
+	}
+		if (rename(temp, temp1) < 0) {
+	if (!Quiet) {
+		fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
+	}
+	test_failed();
+		}
 	}
 
     bitmap = (1<<FILPBIT_LNAME) | (1<<FILPBIT_FNUM );
