@@ -23,8 +23,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -88,8 +88,8 @@ int ret;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -158,8 +158,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -224,8 +224,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -250,35 +250,31 @@ DSI *dsi = &Conn->dsi;
 		fid = filedir.did;
 		FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
 	}
-	if (!Mac) {
-		sprintf(temp, "%s/%s/%s", Path, name1, name);
-		sprintf(temp1,"%s/%s/%s", Path, name1, name2);
+
+	sprintf(temp, "%s/%s/%s", Path, name1, name);
+	sprintf(temp1,"%s/%s/%s", Path, name1, name2);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
+	if (rename(temp, temp1) < 0) {
 		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 		}
+		test_failed();
+	}
+
+	if (adouble == AD_V2) {
+		sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
+		sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, name2);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
 		if (rename(temp, temp1) < 0) {
 			if (!Quiet) {
 				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 			}
 			test_failed();
 		}
-
-        if (adouble == AD_V2) {
-            sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
-            sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, name2);
-		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
-		}
-            if (rename(temp, temp1) < 0) {
-		if (!Quiet) {
-			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-		}
-                test_failed();
-            }
-        }
-	}
-	else {
-		FAIL (FPMoveAndRename(Conn, vol, DIRDID_ROOT, dir, name, name2))
 	}
 	if (FPGetFileDirParams(Conn, vol,  dir , name2, bitmap,0)) {
 		test_failed();
@@ -288,7 +284,7 @@ DSI *dsi = &Conn->dsi;
 		afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
 		if (fid != filedir.did) {
 			if (!Quiet) {
-				fprintf(stdout,"\tFAILED FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
+				fprintf(stdout,"\tNOTE FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
 			}
 			test_failed();
 
@@ -374,8 +370,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -416,39 +412,36 @@ DSI *dsi = &Conn->dsi;
 		fid = filedir.did;
 		FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
 	}
-	if (!Mac) {
-		sprintf(temp, "%s/%s/%s", Path, name1, name);
-		sprintf(temp1,"%s/%s/%s", Path, name1, name2);
+
+	sprintf(temp, "%s/%s/%s", Path, name1, name);
+	sprintf(temp1,"%s/%s/%s", Path, name1, name2);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
+	if (rename(temp, temp1) < 0) {
 		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 		}
+		test_failed();
+	}
+
+	if (adouble == AD_V2) {
+		sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
+		sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, name2);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
 		if (rename(temp, temp1) < 0) {
 			if (!Quiet) {
 				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 			}
 			test_failed();
 		}
+		if (get_fs_lock(name1, name3) < 0) {
+			goto fin;
+		}
+	}
 
-        if (adouble == AD_V2) {
-            sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
-            sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name1, name2);
-		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
-		}
-            if (rename(temp, temp1) < 0) {
-		if (!Quiet) {
-			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-		}
-                test_failed();
-            }
-            if (get_fs_lock(name1, name3) < 0) {
-                goto fin;
-            }
-        }
-	}
-	else {
-		FAIL (FPMoveAndRename(Conn, vol, DIRDID_ROOT, dir, name, name2))
-	}
 	if (FPGetFileDirParams(Conn, vol,  dir , name2, bitmap,0)) {
 		test_failed();
 	}
@@ -457,7 +450,7 @@ DSI *dsi = &Conn->dsi;
 		afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
 		if (fid != filedir.did) {
 			if (!Quiet) {
-				fprintf(stdout,"\tFAILED FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
+				fprintf(stdout,"\tNOTE FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
 			}
 			test_failed();
 
@@ -466,10 +459,8 @@ DSI *dsi = &Conn->dsi;
 			FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
 		}
 	}
-	if (!Mac) {
-		if (get_fs_lock(name1, name3) < 0) {
-			goto fin;
-		}
+	if (get_fs_lock(name1, name3) < 0) {
+		goto fin;
 	}
 
 fin:
@@ -540,8 +531,8 @@ STATIC void test412()
 uint16_t vol = VolID;
 int  dir1, dir2;
 char *name  = "t412 file";
-char *ndir2 = "t412 dir dest";
 char *ndir1 = "t412 dir";
+char *ndir2 = "t412 dir dest";
 int  ofs =  3 * sizeof( uint16_t );
 uint16_t bitmap = (1<<FILPBIT_FNUM ) | (1<<DIRPBIT_FINFO);
 struct afp_filedir_parms filedir;
@@ -550,8 +541,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -577,23 +568,18 @@ DSI *dsi = &Conn->dsi;
 	fid = filedir.did;
 	FAIL (FPResolveID(Conn, vol, fid, bitmap))
 
-	if (!Mac) {
-		sprintf(temp, "%s/%s", Path, ndir1);
-		sprintf(temp1,"%s/%s/%s", Path, ndir2, ndir1);
+	sprintf(temp, "%s/%s", Path, ndir1);
+	sprintf(temp1,"%s/%s/%s", Path, ndir2, ndir1);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
+	if (rename(temp, temp1) < 0) {
 		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
-		}
-		if (rename(temp, temp1) < 0) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-			}
-			test_failed();
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
 		}
+		test_failed();
 	}
-	else {
-		/* FIXME */
-		FAIL (FPMoveAndRename(Conn, vol, DIRDID_ROOT, dir1, name, ndir2))
-	}
+
 	FPResolveID(Conn, vol, fid, bitmap);
 
 	if (FPEnumerate(Conn, vol,  dir2, "",
@@ -610,20 +596,20 @@ DSI *dsi = &Conn->dsi;
 
 	if (FPGetFileDirParams(Conn, vol,  dir1 , name, bitmap,0)) {
 		test_failed();
+		goto fin;
+	}
+
+	filedir.isdir = 0;
+	afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
+	if (fid != filedir.did) {
+		if (!Quiet) {
+			fprintf(stdout,"\tNOTE FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
+		}
+		test_failed();
+
 	}
 	else {
-		filedir.isdir = 0;
-		afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
-		if (fid != filedir.did) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
-			}
-			test_failed();
-
-		}
-		else {
-			FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
-		}
+		FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
 	}
 
 fin:
@@ -631,7 +617,7 @@ fin:
 	FAIL (FPDelete(Conn, vol,  dir1, ""))
 	FAIL (FPDelete(Conn, vol,  dir2, ""))
 test_exit:
-	exit_test("FPResolveID:test412: Resolve ID file modified with local fs");
+	exit_test("FPResolveID:test412: Resolve ID file modified with local fs, nested dir");
 
 }
 
@@ -641,8 +627,8 @@ STATIC void test413()
 uint16_t vol = VolID;
 int  dir,dir2;
 char *name  = "t413 file";
-char *name2 = "t413 dir dest";
 char *name1 = "t413 dir";
+char *name2 = "t413 dir dest";
 int  ofs =  3 * sizeof( uint16_t );
 uint16_t bitmap = (1<<FILPBIT_FNUM ) | (1<<DIRPBIT_FINFO);
 struct afp_filedir_parms filedir;
@@ -651,8 +637,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
@@ -673,18 +659,26 @@ DSI *dsi = &Conn->dsi;
 		goto fin;
 	}
 
-	if (FPGetFileDirParams(Conn, vol,  dir , name, bitmap,0)) {
+	filedir.isdir = 0;
+	afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
+	fid = filedir.did;
+	FAIL (FPResolveID(Conn, vol, fid, bitmap))
+
+	sprintf(temp, "%s/%s/%s", Path, name1, name);
+	sprintf(temp1,"%s/%s/%s", Path, name2, name);
+	if (!Quiet) {
+		fprintf(stdout,"rename %s %s\n", temp, temp1);
+	}
+	if (rename(temp, temp1) < 0) {
+		if (!Quiet) {
+			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
+		}
 		test_failed();
 	}
-	else {
-		filedir.isdir = 0;
-		afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
-		fid = filedir.did;
-		FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
-	}
-	if (!Mac) {
-		sprintf(temp, "%s/%s/%s", Path, name1, name);
-		sprintf(temp1,"%s/%s/%s", Path, name2, name);
+
+	if (adouble == AD_V2) {
+		sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
+		sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name2, name);
 		if (!Quiet) {
 			fprintf(stdout,"rename %s %s\n", temp, temp1);
 		}
@@ -694,40 +688,23 @@ DSI *dsi = &Conn->dsi;
 			}
 			test_failed();
 		}
+	}
 
-        if (adouble == AD_V2) {
-            sprintf(temp, "%s/%s/.AppleDouble/%s", Path, name1, name);
-            sprintf(temp1,"%s/%s/.AppleDouble/%s", Path, name2, name);
-		if (!Quiet) {
-			fprintf(stdout,"rename %s %s\n", temp, temp1);
-		}
-            if (rename(temp, temp1) < 0) {
-		if (!Quiet) {
-			fprintf(stdout,"\tFAILED unable to rename %s to %s :%s\n", temp, temp1, strerror(errno));
-		}
-                test_failed();
-            }
-        }
-	}
-	else {
-		/* FIXME */
-		FAIL (FPMoveAndRename(Conn, vol, DIRDID_ROOT, dir, name, name2))
-	}
 	if (FPGetFileDirParams(Conn, vol,  dir2 , name, bitmap,0)) {
 		test_failed();
+		goto fin;
+	}
+
+	filedir.isdir = 0;
+	afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
+	if (fid != filedir.did) {
+		if (!Quiet) {
+			fprintf(stdout,"\tNOTE FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
+		}
+		test_failed();
 	}
 	else {
-		filedir.isdir = 0;
-		afp_filedir_unpack(&filedir, dsi->data +ofs, bitmap, 0);
-		if (fid != filedir.did) {
-			if (!Quiet) {
-				fprintf(stdout,"\tFAILED FPGetFileDirParams id differ %x %x\n", fid, filedir.did);
-			}
-			test_failed();
-		}
-		else {
-			FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
-		}
+		FAIL (FPResolveID(Conn, vol, filedir.did, bitmap))
 	}
 
 fin:
@@ -736,7 +713,7 @@ fin:
 	FAIL (FPDelete(Conn, vol,  dir, ""))
 	FAIL (FPDelete(Conn, vol,  dir2, ""))
 test_exit:
-	exit_test("FPResolveID:test413: Resolve ID file modified with local fs");
+	exit_test("FPResolveID:test413: Resolve ID file modified with local fs, rename dir");
 
 }
 
@@ -757,8 +734,8 @@ DSI *dsi = &Conn->dsi;
 
 	ENTER_TEST
 
-	if (!Mac && Path[0] == '\0') {
-		test_skipped(T_MAC_PATH);
+	if (Path[0] == '\0') {
+		test_skipped(T_PATH);
 		goto test_exit;
 	}
 
