@@ -831,9 +831,11 @@ void test_skipped(int why)
 	case T_AFP32:
 		s = "AFP 3.2 or higher";
 		break;
+/*
 	case T_MAC_PATH:
 		s = "Mac OS server or volume path";
 		break;
+*/
 	case T_UNIX_PREV:
 		s ="volume with UNIX privileges";
 		break;
@@ -891,6 +893,9 @@ void test_skipped(int why)
 	case T_NONDETERM:
 		s = "nondeterministic behavior";
 		break;
+	case T_BIGENDIAN:
+		s = "not big-endian compatible";
+		break;
 	}
 	if (Color) {
 		snprintf(skipped_msg_buf, sizeof(skipped_msg_buf), ANSI_BBLUE "SKIPPED (%s)" ANSI_NORMAL, s);
